@@ -25,7 +25,7 @@ from flightcondition.units import unit, check_dimensioned,\
 class Layer(DimensionalData):
     """Class to compute and store layer data. """
 
-    varnames = {
+    full_names = {
         'name': 'layer_name',
         'H_base': 'base_geopotential_height',
         'T_base': 'base_geopotential_temperature',
@@ -33,14 +33,17 @@ class Layer(DimensionalData):
         'p_base': 'base_static_pressure',
     }
 
-    def __init__(self, H_arr):
+    def __init__(self, H_arr, full_output=True, units=None):
         """Initialize Layer nested class.
 
         Args:
             H_arr (length): Geopotential altitude
-
+            full_output (bool): Set to True for full output
+            units (str): Set to 'US' for US units or 'SI' for SI
         """
         H_arr = np.atleast_1d(H_arr)
+        self.full_output = full_output
+        self.units = units
 
         self._layer_name = [""]*np.size(H_arr)
         self._H_base = np.zeros_like(H_arr) * unit('m')
@@ -57,8 +60,8 @@ class Layer(DimensionalData):
             self._p_base[idx] = Atmo.p_base[jdx]
 
         # Initialize access by full quantity name through .byname.<name>
-        self.byname = AliasAttributes(varsobj_arr=[self, ],
-                                      varnames_dict_arr=[__class__.varnames, ])
+        self.byname = AliasAttributes(
+            varsobj_arr=[self, ], full_names_dict_arr=[__class__.full_names, ])
 
     @staticmethod
     def _layer_idx(H):
@@ -78,16 +81,85 @@ class Layer(DimensionalData):
         else:  # no break
             raise ValueError("H out of bounds.")
 
-    def tostring(self, full_output=True):
+    def tostring(self, full_output=None, units=None, max_sym_chars=None,
+                 max_name_chars=None, pretty_print=True):
         """Output string representation of class object.
 
         Args:
             full_output (bool): Set to True for full output
+            units (str): Set to 'US' for US units or 'SI' for SI
+            max_sym_chars (int): Maximum characters in symbol name
+            max_name_chars (int): Maximum characters iin full name
+            pretty_print (bool): Pretty print output
 
         Returns:
             str: String representation
         """
-        return str(super().asdict())
+        # Determine full output flag
+        if full_output is None:
+            if self.full_output is None:
+                full_output = True
+            else:
+                full_output = self.full_output
+
+        if units is not None:
+            self.units = units
+
+        if self.units == 'US':
+            H_base_units   = 'kft'
+            T_base_units   = 'degR'
+            T_grad_units   = 'degR/kft'
+            p_base_units   = 'lbf/ft^2'
+        else:  # SI units
+            H_base_units   = 'km'
+            T_base_units   = 'degK'
+            T_grad_units   = 'degK/km'
+            p_base_units   = 'Pa'
+
+        # Insert longer variable name into output
+        if max_sym_chars is None:
+            max_sym_chars = max([len(v) for v in self.full_names.keys()])
+        if max_name_chars is None:
+            max_name_chars = max([len(v) for v in self.full_names.values()])
+
+        H_base_str = self._vartostr(var=self.H_base, var_str='H_base',
+                                    to_units=H_base_units,
+                                    max_sym_chars=max_sym_chars,
+                                    max_name_chars=max_name_chars,
+                                    fmt_val="10.5g", pretty_print=pretty_print)
+        T_base_str = self._vartostr(var=self.T_base, var_str='T_base',
+                                    to_units=T_base_units,
+                                    max_sym_chars=max_sym_chars,
+                                    max_name_chars=max_name_chars,
+                                    fmt_val="10.5g", pretty_print=pretty_print)
+        T_grad_str = self._vartostr(var=self.T_grad, var_str='T_grad',
+                                    to_units=T_grad_units,
+                                    max_sym_chars=max_sym_chars,
+                                    max_name_chars=max_name_chars,
+                                    fmt_val="10.5g", pretty_print=pretty_print)
+        p_base_str = self._vartostr(var=self.p_base, var_str='p_base',
+                                    to_units=p_base_units,
+                                    max_sym_chars=max_sym_chars,
+                                    max_name_chars=max_name_chars,
+                                    fmt_val="10.5g", pretty_print=pretty_print)
+
+        # Create layer string
+        if type(self.name) is np.str_:  # singular array
+            trunc_layer_name = self.name
+        else:  # truncate layer name to no more than 10 character
+            trunc_layer_name = [f"{s[:10]}" for s in self.name]
+        layer_str = self._vartostr(var=trunc_layer_name, var_str='name',
+                                   to_units=None, max_sym_chars=max_sym_chars,
+                                   max_name_chars=max_name_chars,
+                                   fmt_val="", pretty_print=False)
+
+        # Assemble output string
+        if full_output:
+            repr_str = (f"{layer_str}\n{H_base_str}\n{T_base_str}\n"
+                        f"{T_grad_str}\n{p_base_str}")
+        else:
+            repr_str = (f"{layer_str}")
+        return repr_str
 
     @property
     def name(self):
@@ -150,7 +222,7 @@ class Atmosphere(DimensionalData):
         # >>> The mean free path = [7.25e-08 4.04e-05 0.00564] yd
     """
 
-    varnames = {
+    full_names = {
         'h': 'geometric_altitude',
         'H': 'geopotential_altitude',
         'p': 'pressure',
@@ -164,14 +236,26 @@ class Atmosphere(DimensionalData):
         'MFP': 'mean_free_path',
     }
 
-    def __init__(self, h=None, units="", **kwargs):
+    def __init__(self, h=None, units=None, full_output=None, **kwargs):
         """Input geometric altitude - object contains the corresponding
         atmospheric quantities.
 
+        See class definition for special hidden arguments such as `h_kft` to
+        input a scalar that automatically converts to the kilo-foot dimension,
+        or `h_km` for kilometers.
+
         Args:
             h (length): Geometric altitude - aliases are 'alt', 'altitude'
             units (str): Set to 'US' for US units or 'SI' for SI
+            full_output (bool): Set to True for full output
         """
+        self.full_output = full_output
+        # Check units and set initially
+        if units in dir(unit.sys):
+            self.units = units
+        else:
+            self.units = 'SI'
+
         # Compute altitude bounds
         self._H_min = Atmo.H_base[0]
         self._H_max = Atmo.H_base[-1]
@@ -180,36 +264,49 @@ class Atmosphere(DimensionalData):
 
         # Process altitude input
         # Check for hidden aliases
-        h_aliases = ['alt', 'altitude']
+        h_aliases = ['alt', 'altitude', 'z']
         if h is None:
             h = __class__._arg_from_alias(h_aliases, kwargs)
 
+        # Check if special h_kft syntactic sugar is used
+        h_kft_aliases = ['h_kft', 'z_kft', 'kft']
+        if h is None:
+            h_kft = __class__._arg_from_alias(h_kft_aliases, kwargs)
+            if h_kft is not None:
+                h = h_kft * unit('kft')
+
+        # Check if special h_km syntactic sugar is used
+        h_km_aliases = ['h_km', 'z_km', 'km']
+        if h is None:
+            h_km = __class__._arg_from_alias(h_km_aliases, kwargs)
+            if h_km is not None:
+                h = h_km * unit('km')
+
         # Default to 0 kft
         if h is None:
             h = 0 * unit('ft')
         self.h = h
 
-        # Process unit system
+        # Further process unit system
         if units not in dir(unit.sys):  # check if usable system
             if check_US_length_units(h):
                 self.units = 'US'
             else:
                 self.units = 'SI'
-        else:
-            self.units = units
 
         # Initialize access by full quantity name through .byname.<name>
-        self.byname = AliasAttributes(varsobj_arr=[self, ],
-                                      varnames_dict_arr=[__class__.varnames, ])
+        self.byname = AliasAttributes(
+            varsobj_arr=[self, ], full_names_dict_arr=[__class__.full_names, ])
 
-    def tostring(self, full_output=True, units=None, max_var_chars=0,
-                 pretty_print=True):
+    def tostring(self, full_output=None, units=None, max_sym_chars=None,
+                 max_name_chars=None, pretty_print=True):
         """String representation of data structure.
 
         Args:
             full_output (bool): Set to True for full output
             units (str): Set to 'US' for US units or 'SI' for SI
-            max_var_chars (int): Maximum number of characters in unit string
+            max_sym_chars (int): Maximum characters in symbol name
+            max_name_chars (int): Maximum characters iin full name
             pretty_print (bool): Pretty print output
 
         Returns:
@@ -244,56 +341,74 @@ class Atmosphere(DimensionalData):
             MFP_units = 'm'
 
         # Insert longer variable name into output
-        max_var_chars = max([
-            max([len(v) for v in __class__.varnames.values()]),
-            max_var_chars
-        ])
+        if max_sym_chars is None:
+            max_sym_chars = max([len(v) for v in self.full_names.keys()])
+        if max_name_chars is None:
+            max_name_chars = max([len(v) for v in self.full_names.values()])
+
         h_str = self._vartostr(var=self.h, var_str='h', to_units=h_units,
-                               max_var_chars=max_var_chars,
+                               max_sym_chars=max_sym_chars,
+                               max_name_chars=max_name_chars,
                                fmt_val="10.5g", pretty_print=pretty_print)
         H_str = self._vartostr(var=self.H, var_str='H', to_units=H_units,
-                               max_var_chars=max_var_chars,
+                               max_sym_chars=max_sym_chars,
+                               max_name_chars=max_name_chars,
                                fmt_val="10.5g", pretty_print=pretty_print)
         p_str = self._vartostr(var=self.p, var_str='p', to_units=p_units,
-                               max_var_chars=max_var_chars,
+                               max_sym_chars=max_sym_chars,
+                               max_name_chars=max_name_chars,
                                fmt_val="10.5g", pretty_print=pretty_print)
         T_str = self._vartostr(var=self.T, var_str='T', to_units=T_units,
-                               max_var_chars=max_var_chars,
+                               max_sym_chars=max_sym_chars,
+                               max_name_chars=max_name_chars,
                                fmt_val="10.5g", pretty_print=pretty_print)
+        fmt_val_rho = "10.4e" if units == 'US' else "10.5g"
         rho_str = self._vartostr(var=self.rho, var_str='rho',
                                  to_units=rho_units,
-                                 max_var_chars=max_var_chars,
-                                 fmt_val="10.5g", pretty_print=pretty_print)
+                                 max_sym_chars=max_sym_chars,
+                                 max_name_chars=max_name_chars,
+                                 fmt_val=fmt_val_rho,
+                                 pretty_print=pretty_print)
         a_str = self._vartostr(var=self.a, var_str='a', to_units=a_units,
-                               max_var_chars=max_var_chars,
+                               max_sym_chars=max_sym_chars,
+                               max_name_chars=max_name_chars,
                                fmt_val="10.5g", pretty_print=pretty_print)
         mu_str = self._vartostr(var=self.mu, var_str='mu', to_units=mu_units,
-                                max_var_chars=max_var_chars,
+                                max_sym_chars=max_sym_chars,
+                                max_name_chars=max_name_chars,
                                 fmt_val="10.4e", pretty_print=pretty_print)
         nu_str = self._vartostr(var=self.nu, var_str='nu', to_units=nu_units,
-                                max_var_chars=max_var_chars,
+                                max_sym_chars=max_sym_chars,
+                                max_name_chars=max_name_chars,
                                 fmt_val="10.4e", pretty_print=pretty_print)
         k_str = self._vartostr(var=self.k, var_str='k', to_units=k_units,
-                               max_var_chars=max_var_chars,
+                               max_sym_chars=max_sym_chars,
+                               max_name_chars=max_name_chars,
                                fmt_val="10.4e", pretty_print=pretty_print)
         g_str = self._vartostr(var=self.g, var_str='g', to_units=g_units,
-                               max_var_chars=max_var_chars,
+                               max_sym_chars=max_sym_chars,
+                               max_name_chars=max_name_chars,
                                fmt_val="10.5g", pretty_print=pretty_print)
         MFP_str = self._vartostr(var=self.MFP, var_str='MFP',
                                  to_units=MFP_units,
-                                 max_var_chars=max_var_chars,
+                                 max_sym_chars=max_sym_chars,
+                                 max_name_chars=max_name_chars,
                                  fmt_val="10.4e", pretty_print=pretty_print)
 
-        if full_output:
-            if type(self.layer.name) is np.str_:  # singular string
-                trunc_layer_name = self.layer.name
-            else:
-                trunc_layer_name = "[" + " ".join([
-                    f"{s[:10]}" for s in self.layer.name
-                ]) + "]"
-            layer_str = (f"{'atmospheric_layer ':{max_var_chars}} name    = "
-                         f"{trunc_layer_name}")
+        # Create layer string
+        layer_str = self.layer.tostring(full_output=False,
+                                        max_sym_chars=max_sym_chars,
+                                        max_name_chars=max_name_chars)
 
+        # Determine full output flag
+        if full_output is None:
+            if self.full_output is None:
+                full_output = True
+            else:
+                full_output = self.full_output
+
+        # Assemble output string
+        if full_output:
             repr_str = (f"{h_str}\n{H_str}\n{p_str}\n{T_str}\n{rho_str}\n"
                         f"{a_str}\n{mu_str}\n{nu_str}\n{k_str}\n{g_str}\n"
                         f"{MFP_str}\n{layer_str}")
@@ -378,6 +493,27 @@ class Atmosphere(DimensionalData):
         else:
             self._units = units
             unit.default_system = units
+            if hasattr(self, 'layer'):
+                self.layer.units = units
+
+    @property
+    def full_output(self):
+        """Enable or disable full output of data by default.
+
+        Returns:
+            bool: Full output flag
+        """
+        return self._full_output
+
+    @full_output.setter
+    def full_output(self, full_output):
+        """Unit system to use: 'SI', 'US', etc.  Available unit systems given
+        by dir(unit.sys).
+
+        Args:
+            full_output (bool): Full output flag
+        """
+        self._full_output = full_output
 
     @_property_decorators
     def h(self):
@@ -418,7 +554,8 @@ class Atmosphere(DimensionalData):
         # Update quantities
         self._h = h
         self._H = self._H_from_h(self.h)
-        self.layer = Layer(self.H)
+        self.layer = Layer(self.H, full_output=self.full_output,
+                           units=self.units)
 
     @_property_decorators
     def H(self):
